@@ -67,10 +67,10 @@ if (any(nas) & any(nas.g))  {
     sr2 <- sum(e^2)/(n - df)
     r2 <- 1 - sum(e^2)/sum(ycen^2)
     out <- list(call = C, beta.est = beta.est, fitted.values =object.lm$fitted.values,
-    svd.fdata=pc,pf = pf,coefficients=object.lm$coefficients,residuals = object.lm$residuals,
-    df = df,r2=r2, sr2 = sr2,H=H,fdataobj = fdataobj,y = y, l = l, pc=pc,lm=object.lm,Z=Z)
+    svd.fdata=pc,coefficients=object.lm$coefficients,residuals = object.lm$residuals,
+    df = df,r2=r2, sr2 = sr2,H=H,fdataobj = fdataobj,y = y, l = l,lm=object.lm,pc=pc)
+    #pc=pc,pf = pf,Z=Z
     class(out) = "fregre.fd"
     return(out)
 }
 
-
