@@ -13,7 +13,7 @@ Xcen.fdata <- mm$Xcen
 n <- nrow(Xcen.fdata);J <- ncol(Xcen.fdata)
 Jmin<-min(c(J,n))
 eigenres <- svd(Xcen.fdata$data)
-lambdas <- eigenres$d^2/(n-1)
+lambdas <- eigenres$d^2/n
 vs<-fdata(t(eigenres$v),tt,rtt,list(main="pc.svd.fdata",xlab="t",ylab="rotation"))
 scores <- matrix(0,ncol=J,nrow=n)
 if (norm) {
@@ -21,8 +21,9 @@ if (norm) {
           vs$data<-sweep(vs$data,1,drop(no),"/")
           scores[,1:Jmin] <-inprod.fdata(Xcen.fdata,vs)
           }
-else     {scores[,1:Jmin] <-inprod.fdata(Xcen.fdata,vs)}
-#else     {scores[,1:Jmin] <-Xcen.fdata$data%*%t(eigenres$v)*diff(rtt)/J}
+#else     {scores[,1:Jmin] <-inprod.fdata(Xcen.fdata,vs)}
+else     {scores[,1:Jmin] <-Xcen.fdata$data%*%(eigenres$v)*diff(rtt)/(J-1)}
 colnames(scores)<-paste("PC",1:J, sep = "")
 return(list("lambdas"=lambdas,"rotation"=vs,"x"=scores,"fdataobj.cen"=Xcen.fdata,"mean"=xmean))
 }
+
